@@ -1,4 +1,4 @@
 pub mod sparse_matrix;
-pub(crate) mod sparse_scalar;
+pub mod sparse_scalar;
 pub mod sparse_vector;
 pub mod value_type;
